==> 2.0.0.tar.gz: lib/src/widgets/mixins/android_platform_view_mixin.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

import '../../utils/fw_logger_util.dart';

typedef AndroidPlatformViewBuilder = Widget Function(
    BuildContext context, ValueKey key);

mixin AndroidPlatformViewMixin<T extends StatefulWidget> on State<T> {
  double androidMarginRight = 0;
  final _androidContainerKey = GlobalKey();
  double? _androidOverflowBoxWidth;
  bool _androidPlatformViewLayoutInited = true;
  final _enableDebugLog = false;

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addPostFrameCallback((_) {
      _updateLayout();
    });
  }

  Widget buildAndroidPlatformView(AndroidPlatformViewBuilder builder) {
    final key =
        "androidOverflowBoxWidth:${(_androidOverflowBoxWidth ?? 0).floor()}_androidMarginRight:${androidMarginRight.floor()}";
    return NotificationListener<SizeChangedLayoutNotification>(
      onNotification: _onSizeChanged,
      child: SizeChangedLayoutNotifier(
        child: Container(
          key: _androidContainerKey,
          child: OverflowBox(
            alignment: Alignment.centerLeft,
            minWidth: _androidOverflowBoxWidth,
            maxWidth: _androidOverflowBoxWidth,
            child: _androidPlatformViewLayoutInited
                ? builder(context, ValueKey(key))
                : null,
          ),
        ),
      ),
    );
  }

  bool _onSizeChanged(SizeChangedLayoutNotification notification) {
    if (_enableDebugLog) {
      FWLoggerUtil.log("AndroidPlatformViewMixin onSizeChanged $notification");
    }
    WidgetsBinding.instance.addPostFrameCallback((_) {
      _updateLayout();
    });
    return false;
  }

  RenderObject? _findAncestorFullScreenWidthRenderObject(AbstractNode? node) {
    if (node == null) {
      return null;
    }

    final screenWidth = MediaQuery.of(context).size.width;
    if (node is RenderBox) {
      if (node.size.width.floor() == screenWidth.floor()) {
        return node;
      }
    }

    return _findAncestorFullScreenWidthRenderObject(node.parent);
  }

  void _updateLayout() {
    try {
      if (defaultTargetPlatform == TargetPlatform.android &&
          _androidContainerKey.currentContext != null &&
          mounted) {
        final renderbox = _androidContainerKey.currentContext!
            .findRenderObject() as RenderBox;
        final ancestor =
            _findAncestorFullScreenWidthRenderObject(renderbox.parent);
        if (_enableDebugLog) {
          FWLoggerUtil.log("AndroidPlatformViewMixin ancestor: $ancestor");
        }
        Offset topLeft =
            renderbox.localToGlobal(Offset.zero, ancestor: ancestor);
        final screenWidth = MediaQuery.of(context).size.width;
        final newAndroidMarginRight =
            (screenWidth - topLeft.dx - renderbox.size.width).floorToDouble();
        final newAndroidOverflowBoxWidth =
            (screenWidth - topLeft.dx).floorToDouble();
        if (_enableDebugLog) {
          FWLoggerUtil.log(
              "AndroidPlatformViewMixin _updateLayout screenWidth $screenWidth topLeft.dx ${topLeft.dx} renderbox.size.width ${renderbox.size.width} newAndroidMarginRight: $newAndroidMarginRight newAndroidOverflowBoxWidth: $newAndroidOverflowBoxWidth ${DateTime.now()}");
        }
        if (newAndroidMarginRight.isFinite &&
            newAndroidOverflowBoxWidth.isFinite &&
            newAndroidMarginRight > 0 &&
            newAndroidOverflowBoxWidth > 0) {
          _updateAndroidLayoutProperties(
            newAndroidOverflowBoxWidth: newAndroidOverflowBoxWidth,
            newAndroidMarginRight: newAndroidMarginRight,
          );
        } else {
          _updateAndroidLayoutProperties(
            newAndroidOverflowBoxWidth: null,
            newAndroidMarginRight: 0,
          );
        }
      }
    } catch (e) {
      FWLoggerUtil.log("PlatformViewMixin _updateLayout error: $e");
    }
  }

  void _updateAndroidLayoutProperties({
    required double? newAndroidOverflowBoxWidth,
    required double newAndroidMarginRight,
  }) {
    final shouldReBuild =
        _androidOverflowBoxWidth != newAndroidOverflowBoxWidth ||
            androidMarginRight != newAndroidMarginRight ||
            !_androidPlatformViewLayoutInited;
    if (shouldReBuild && mounted) {
      setState(() {
        _androidOverflowBoxWidth = newAndroidOverflowBoxWidth;
        androidMarginRight = newAndroidMarginRight;
        _androidPlatformViewLayoutInited = true;
      });
    }
  }
}

==> 2.0.4.tar.gz: lib/src/widgets/mixins/android_platform_view_mixin.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

import '../../utils/fw_logger_util.dart';

typedef AndroidPlatformViewBuilder = Widget Function(
    BuildContext context, ValueKey key);

mixin AndroidPlatformViewMixin<T extends StatefulWidget> on State<T> {
  double androidMarginRight = 0;
  final _androidContainerKey = GlobalKey();
  double? _androidOverflowBoxWidth;
  bool _androidPlatformViewLayoutInited = true;
  final _enableDebugLog = false;

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addPostFrameCallback((_) {
      _updateLayout();
    });
  }

  Widget buildAndroidPlatformView(AndroidPlatformViewBuilder builder) {
    final key =
        "androidOverflowBoxWidth:${_androidOverflowBoxWidth?.floor().toString() ?? ""}_androidMarginRight:${androidMarginRight.floor()}";
    return NotificationListener<SizeChangedLayoutNotification>(
      onNotification: _onSizeChanged,
      child: SizeChangedLayoutNotifier(
        child: Container(
          key: _androidContainerKey,
          child: OverflowBox(
            alignment: Alignment.centerLeft,
            minWidth: _androidOverflowBoxWidth,
            maxWidth: _androidOverflowBoxWidth,
            child: _androidPlatformViewLayoutInited
                ? builder(context, ValueKey(key))
                : null,
          ),
        ),
      ),
    );
  }

  bool _onSizeChanged(SizeChangedLayoutNotification notification) {
    if (_enableDebugLog) {
      FWLoggerUtil.log("AndroidPlatformViewMixin onSizeChanged $notification");
    }
    WidgetsBinding.instance.addPostFrameCallback((_) {
      _updateLayout();
    });
    return false;
  }

  RenderObject? _findAncestorFullScreenWidthRenderObject(AbstractNode? node) {
    if (node == null) {
      return null;
    }

    final screenWidth = MediaQuery.of(context).size.width;
    if (node is RenderBox) {
      if (node.size.width.floor() == screenWidth.floor()) {
        return node;
      }
    }

    return _findAncestorFullScreenWidthRenderObject(node.parent);
  }

  void _updateLayout() {
    try {
      if (defaultTargetPlatform == TargetPlatform.android &&
          _androidContainerKey.currentContext != null &&
          mounted) {
        final renderbox = _androidContainerKey.currentContext!
            .findRenderObject() as RenderBox;
        final ancestor =
            _findAncestorFullScreenWidthRenderObject(renderbox.parent);
        if (_enableDebugLog) {
          FWLoggerUtil.log("AndroidPlatformViewMixin ancestor: $ancestor");
        }
        Offset topLeft =
            renderbox.localToGlobal(Offset.zero, ancestor: ancestor);
        final screenWidth = MediaQuery.of(context).size.width;
        final newAndroidMarginRight =
            (screenWidth - topLeft.dx - renderbox.size.width).floorToDouble();
        final newAndroidOverflowBoxWidth =
            (screenWidth - topLeft.dx).floorToDouble();
        if (_enableDebugLog) {
          FWLoggerUtil.log(
              "AndroidPlatformViewMixin _updateLayout screenWidth $screenWidth topLeft.dx ${topLeft.dx} renderbox.size.width ${renderbox.size.width} newAndroidMarginRight: $newAndroidMarginRight newAndroidOverflowBoxWidth: $newAndroidOverflowBoxWidth ${DateTime.now()}");
        }
        if (newAndroidMarginRight.isFinite &&
            newAndroidOverflowBoxWidth.isFinite &&
            newAndroidMarginRight > 0 &&
            newAndroidOverflowBoxWidth > 0) {
          _updateAndroidLayoutProperties(
            newAndroidOverflowBoxWidth: newAndroidOverflowBoxWidth,
            newAndroidMarginRight: newAndroidMarginRight,
          );
        } else {
          _updateAndroidLayoutProperties(
            newAndroidOverflowBoxWidth: null,
            newAndroidMarginRight: 0,
          );
        }
      }
    } catch (e) {
      FWLoggerUtil.log("PlatformViewMixin _updateLayout error: $e");
    }
  }

  void _updateAndroidLayoutProperties({
    required double? newAndroidOverflowBoxWidth,
    required double newAndroidMarginRight,
  }) {
    final shouldReBuild =
        _androidOverflowBoxWidth != newAndroidOverflowBoxWidth ||
            androidMarginRight != newAndroidMarginRight ||
            !_androidPlatformViewLayoutInited;
    if (shouldReBuild && mounted) {
      setState(() {
        _androidOverflowBoxWidth = newAndroidOverflowBoxWidth;
        androidMarginRight = newAndroidMarginRight;
        _androidPlatformViewLayoutInited = true;
      });
    }
  }
}
